@@ -1,9 +1,11 @@
 from .code import Code
 from .payments import Payment
 from .account import Account
+from .preauthorize import PreAuthorize
 
 __all__ = [
         'Code',
         'Payment',
         'Account',
+        'PreAuthorize',
 ]
