@@ -8,7 +8,9 @@ class Code(Resource):
         super(Code, self).__init__(client)
         self.base_url = URL.CODE
 
-    def create_qr_code(self, data={}, **kwargs):
+    def create_qr_code(self, data=None, **kwargs):
+        if data is None:
+            data = {}
         url = self.base_url
         if "requestedAt" not in data:
             data['requestedAt'] = int(datetime.datetime.now().timestamp())
@@ -43,7 +45,8 @@ class Code(Resource):
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for codeId")
-        return self.delete(id)
+        url = "{}/{}".format(self.base_url, id)
+        return self.delete(None, url, **kwargs)
 
     def get_payment_details(self, id=None, **kwargs):
         if id is None:
@@ -56,11 +59,13 @@ class Code(Resource):
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantPaymentId")
-        url = "{}/{}".format('payments', id)
+        url = "{}/{}".format('/v2/payments', id)
         return self.delete(None, url, **kwargs)
 
-    def capture_payment(self, data={}, **kwargs):
-        url = "{}/{}".format('payments', 'capture')
+    def capture_payment(self, data=None, **kwargs):
+        if data is None:
+            data = {}
+        url = "{}/{}".format('/v2/payments', 'capture')
         if "requestedAt" not in data:
             data['requestedAt'] = int(datetime.datetime.now().timestamp())
         if "merchantPaymentId" not in data:
@@ -83,8 +88,10 @@ class Code(Resource):
                              "\x1b[0m for currency")
         return self.post_url(url, data, **kwargs)
 
-    def revert_payment(self, data={}, **kwargs):
-        url = "{}/{}/{}".format('payments', 'preauthorize', 'revert')
+    def revert_payment(self, data=None, **kwargs):
+        if data is None:
+            data = {}
+        url = "{}/{}/{}".format('/v2/payments', 'preauthorize', 'revert')
         if "requestedAt" not in data:
             data['requestedAt'] = int(datetime.datetime.now().timestamp())
         if "merchantRevertId" not in data:
@@ -95,8 +102,10 @@ class Code(Resource):
                              " \x1b[0m for merchantPaymentId")
         return self.post_url(url, data, **kwargs)
 
-    def refund_payment(self, data={}, **kwargs):
-        url = "/{}".format('refunds')
+    def refund_payment(self, data=None, **kwargs):
+        if data is None:
+            data = {}
+        url = "{}/".format('/v2/refunds')
         if "requestedAt" not in data:
             data['requestedAt'] = int(datetime.datetime.now().timestamp())
         if "merchantRefundId" not in data:
@@ -120,5 +129,5 @@ class Code(Resource):
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantRefundId")
-        url = "/{}/{}".format('refunds', id)
+        url = "{}/{}".format('/v2/refunds', id)
         return self.fetch(None, url, **kwargs)
