@@ -30,21 +30,21 @@ class Payment(Resource):
         return self.post_url(url, data, **kwargs)
 
     def get_payment_details(self, id, **kwargs):
-        url = "{}/{}/{}".format(self.base_url, 'payments', id)
+        url = "{}/{}".format(self.base_url, id)
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantPaymentId")
         return self.fetch(None, url, **kwargs)
 
     def cancel_payment(self, id, **kwargs):
-        url = "{}/{}".format('payments', id)
+        url = "{}/{}".format(self.base_url, id)
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantPaymentId")
         return self.delete(None, url, **kwargs)
 
     def refund_payment(self, data={}, **kwargs):
-        url = "/{}".format('refunds')
+        url = "{}/".format('/v2/refunds')
         if "requestedAt" not in data:
             data['requestedAt'] = datetime.datetime.now().second
         if "merchantPaymentId" not in data:
@@ -64,9 +64,9 @@ class Payment(Resource):
                              " \x1b[0m for currency")
         return self.post_url(url, data, **kwargs)
 
-    def refund_details(self, data={}, **kwargs):
+    def refund_details(self, id=None, **kwargs):
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantRefundId")
-        url = "/{}".format('refunds')
-        return self.fetch(url, data, **kwargs)
+        url = "{}/{}".format('/v2/refunds', id)
+        return self.fetch(None, url, **kwargs)
